All Classes and Interfaces
Class
Description
The request was denied because of insufficient access or permissions.
Unique identifying information for an Android app.
Options for filtering API keys.
API Restrictions on the allowed actions, resources, and referers for an API key resource.
Unique identifying information for an Apple app (iOS, macOS, tvOS and watchOS).
An AWS Arn.
AssociateTrackerConsumerRequest Marshaller
Contains the tracker resource details.
BatchDeleteDevicePositionHistoryRequest Marshaller
Contains error details for each geofence that failed to delete from the geofence collection.
BatchDeleteGeofenceRequest Marshaller
Contains error details for each device that failed to evaluate its position against the geofences in a given geofence
collection.
BatchEvaluateGeofencesRequest Marshaller
Contains error details for each device that didn't return a position.
BatchGetDevicePositionRequest Marshaller
Contains the batch request error details associated with the request.
Contains error details for each geofence that failed to be stored in a given geofence collection.
Contains geofence geometry details.
BatchPutGeofenceRequest Marshaller
Contains a summary of each geofence that was successfully stored in a given geofence collection.
Contains error details for each device that failed to update its position.
BatchUpdateDevicePositionRequest Marshaller
Contains details about additional route preferences for requests that specify
TravelMode as
Car.CalculateRouteMatrixRequest Marshaller
Returns the result of the route matrix calculation.
A summary of the calculated route matrix.
CalculateRouteRequest Marshaller
Returns the result of the route calculation.
A summary of the calculated route.
Contains details about additional route preferences for requests that specify
TravelMode as
Truck.CancelJobRequest Marshaller
The cellular network communication infrastructure that the device uses.
A circle on the earth, as defined by a center point and a radius.
The request was unsuccessful because of a conflict.
CreateGeofenceCollectionRequest MarshallerCreateKeyRequest MarshallerCreateMapRequest MarshallerCreatePlaceIndexRequest MarshallerCreateRouteCalculatorRequest MarshallerCreateTrackerRequest Marshaller
Specifies the data storage option chosen for requesting Places.
DeleteGeofenceCollectionRequest MarshallerDeleteKeyRequest MarshallerDeleteMapRequest MarshallerDeletePlaceIndexRequest MarshallerDeleteRouteCalculatorRequest MarshallerDeleteTrackerRequest MarshallerDescribeGeofenceCollectionRequest MarshallerDescribeKeyRequest MarshallerDescribeMapRequest MarshallerDescribePlaceIndexRequest MarshallerDescribeRouteCalculatorRequest MarshallerDescribeTrackerRequest Marshaller
Contains the device position details.
Contains the position update details for a device.
The device's position, IP address, and Wi-Fi access points.
DisassociateTrackerConsumerRequest MarshallerLink between an endpoint property and the
AwsEndpointAttribute it represents.
A forecasted event represents a geofence event in relation to the requested device state, that may occur given the
provided device state and time horizon.
The device's position and speed.
Represents the output for the
LocationClient.forecastGeofenceEventsPaginator(software.amazon.awssdk.services.location.model.ForecastGeofenceEventsRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.forecastGeofenceEventsPaginator(software.amazon.awssdk.services.location.model.ForecastGeofenceEventsRequest)
operation which is a paginated operation.ForecastGeofenceEventsRequest Marshaller
Contains the geofence geometry details.
Represents the output for the
LocationClient.getDevicePositionHistoryPaginator(software.amazon.awssdk.services.location.model.GetDevicePositionHistoryRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.getDevicePositionHistoryPaginator(software.amazon.awssdk.services.location.model.GetDevicePositionHistoryRequest)
operation which is a paginated operation.GetDevicePositionHistoryRequest MarshallerGetDevicePositionRequest MarshallerGetGeofenceRequest MarshallerGetJobRequest MarshallerGetMapGlyphsRequest MarshallerGetMapSpritesRequest MarshallerGetMapStyleDescriptorRequest MarshallerGetMapTileRequest MarshallerGetPlaceRequest MarshallerIdentifiers for variables declared within the rule engine, e.g.
The inferred state of the device, given the provided position, IP address, cellular signals, and Wi-Fi- access
points.
The request has failed to process because of an unknown server error, exception, or failure.
An intermediate value for JMESPath expressions, encapsulating the different data types supported by JMESPath and
the operations on that data.
Additional options for configuring job action parameters.
Error information for failed jobs.
Configuration for input data location and format.
Configuration for output data location and format.
Criteria for filtering jobs.
Contains the calculated route's details for each path between a pair of positions.
Contains the geometry details for each path between a pair of positions.
Represents the output for the
LocationClient.listDevicePositionsPaginator(software.amazon.awssdk.services.location.model.ListDevicePositionsRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listDevicePositionsPaginator(software.amazon.awssdk.services.location.model.ListDevicePositionsRequest)
operation which is a paginated operation.ListDevicePositionsRequest Marshaller
Contains the tracker resource details.
Represents the output for the
LocationClient.listGeofenceCollectionsPaginator(software.amazon.awssdk.services.location.model.ListGeofenceCollectionsRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listGeofenceCollectionsPaginator(software.amazon.awssdk.services.location.model.ListGeofenceCollectionsRequest)
operation which is a paginated operation.ListGeofenceCollectionsRequest Marshaller
Contains the geofence collection details.
Contains a list of geofences stored in a given geofence collection.
Represents the output for the
LocationClient.listGeofencesPaginator(software.amazon.awssdk.services.location.model.ListGeofencesRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listGeofencesPaginator(software.amazon.awssdk.services.location.model.ListGeofencesRequest)
operation which is a paginated operation.ListGeofencesRequest Marshaller
Represents the output for the
LocationClient.listJobsPaginator(software.amazon.awssdk.services.location.model.ListJobsRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listJobsPaginator(software.amazon.awssdk.services.location.model.ListJobsRequest)
operation which is a paginated operation.ListJobsRequest Marshaller
Job summary information returned in list operations.
Represents the output for the
LocationClient.listKeysPaginator(software.amazon.awssdk.services.location.model.ListKeysRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listKeysPaginator(software.amazon.awssdk.services.location.model.ListKeysRequest)
operation which is a paginated operation.ListKeysRequest Marshaller
An API key resource listed in your Amazon Web Services account.
Represents the output for the
LocationClient.listMapsPaginator(software.amazon.awssdk.services.location.model.ListMapsRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listMapsPaginator(software.amazon.awssdk.services.location.model.ListMapsRequest)
operation which is a paginated operation.ListMapsRequest Marshaller
Contains details of an existing map resource in your Amazon Web Services account.
Represents the output for the
LocationClient.listPlaceIndexesPaginator(software.amazon.awssdk.services.location.model.ListPlaceIndexesRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listPlaceIndexesPaginator(software.amazon.awssdk.services.location.model.ListPlaceIndexesRequest)
operation which is a paginated operation.ListPlaceIndexesRequest Marshaller
A place index resource listed in your Amazon Web Services account.
Represents the output for the
LocationClient.listRouteCalculatorsPaginator(software.amazon.awssdk.services.location.model.ListRouteCalculatorsRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listRouteCalculatorsPaginator(software.amazon.awssdk.services.location.model.ListRouteCalculatorsRequest)
operation which is a paginated operation.ListRouteCalculatorsRequest Marshaller
A route calculator resource listed in your Amazon Web Services account.
ListTagsForResourceRequest Marshaller
Represents the output for the
LocationClient.listTrackerConsumersPaginator(software.amazon.awssdk.services.location.model.ListTrackerConsumersRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listTrackerConsumersPaginator(software.amazon.awssdk.services.location.model.ListTrackerConsumersRequest)
operation which is a paginated operation.ListTrackerConsumersRequest Marshaller
Represents the output for the
LocationClient.listTrackersPaginator(software.amazon.awssdk.services.location.model.ListTrackersRequest)
operation which is a paginated operation.
Represents the output for the
LocationAsyncClient.listTrackersPaginator(software.amazon.awssdk.services.location.model.ListTrackersRequest)
operation which is a paginated operation.ListTrackersRequest Marshaller
Contains the tracker resource details.
Service client for accessing Amazon Location Service asynchronously.
A builder for creating an instance of
LocationAsyncClient.Waiter utility class that polls a resource until a desired state is reached or until it is determined that the
resource will never enter into the desired state.
The parameters object used to resolve the auth schemes for the Location service.
A builder for a
LocationAuthSchemeParams.An auth scheme provider for Location service.
This includes configuration specific to Amazon Location Service that is supported by both
LocationClientBuilder and LocationAsyncClientBuilder.Service client for accessing Amazon Location Service.
A builder for creating an instance of
LocationClient.The parameters object used to resolve an endpoint for the Location service.
An endpoint provider for Location.
Class to expose the service client settings to the user.
A builder for creating a
LocationServiceClientConfigurationWaiter utility class that polls a resource until a desired state is reached or until it is determined that the
resource will never enter into the desired state.
Details about the Long-Term Evolution (LTE) network.
LTE local identification information (local ID).
LTE network measurements.
Specifies the map tile style selected from an available provider.
Specifies the political view for the style.
Contains details about addresses or points of interest that match the search criteria.
Places uses a point geometry to specify a location or a Place.
Defines the level of certainty of the position.
PutGeofenceRequest Marshaller
The resource that you've entered was not found in your AWS account.
The result for the calculated route of one
DeparturePosition DestinationPosition pair.
An error corresponding to the calculation of a route between the
DeparturePosition and
DestinationPosition.Represents a URL to be used internally for endpoint resolution.
Contains a search result from a position search query that is run on a place index resource.
Contains a place suggestion resulting from a place suggestion query that is run on a place index resource.
Contains a search result from a text search query that is run on a place index resource.
SearchPlaceIndexForPositionRequest Marshaller
A summary of the request sent by using
SearchPlaceIndexForPosition.SearchPlaceIndexForSuggestionsRequest Marshaller
A summary of the request sent by using
SearchPlaceIndexForSuggestions.SearchPlaceIndexForTextRequest Marshaller
A summary of the request sent by using
SearchPlaceIndexForText.
The operation was denied because the request would exceed the maximum quota set for Amazon
Location Service.
StartJobRequest Marshaller
Represents an element of a leg within a route.
TagResourceRequest Marshaller
The request was denied because of request throttling.
Information about a time zone.
The geomerty used to filter device positions.
Contains details about the truck dimensions in the unit of measurement that you specify.
Contains details about the truck's weight specifications.
UntagResourceRequest MarshallerUpdateGeofenceCollectionRequest MarshallerUpdateKeyRequest MarshallerUpdateMapRequest MarshallerUpdatePlaceIndexRequest MarshallerUpdateRouteCalculatorRequest MarshallerUpdateTrackerRequest Marshaller
Options specific to address validation jobs.
The input failed to meet the constraints specified by the AWS service.
The input failed to meet the constraints specified by the AWS service in a specified field.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
VerifyDevicePositionRequest MarshallerContains classes used at runtime by the code generator classes for waiter acceptors generated from JMESPath
expressions.
A
WaiterAcceptor implementation that checks for a specific HTTP response status, regardless of whether
it's reported by a response or an exception.
Wi-Fi access point.